let timer = {
    isRunning: false,
    isPaused: false,
    currentPhase: "Learning",
    remainingTime: 30 * 60,
    learningTime: 30 * 60,
    breakTime: 5 * 60,
    intervalId: null
};

function notify(message) {
    chrome.notifications.create({
        type: "basic",
        iconUrl: "icon.png",
        title: "Timer Notification",
        message: message
    });
}

function startTimer() {
    if (timer.intervalId) clearInterval(timer.intervalId);
    timer.isRunning = true;
    timer.isPaused = false;

    timer.intervalId = setInterval(() => {
        if (!timer.isPaused) {
            timer.remainingTime--;

            if (timer.remainingTime <= 0) {
                clearInterval(timer.intervalId);
                notify(`${timer.currentPhase} Time Finished!`);
                timer.currentPhase = timer.currentPhase === "Learning" ? "Break" : "Learning";
                timer.remainingTime = timer.currentPhase === "Learning"
                    ? timer.learningTime
                    : timer.breakTime;
                startTimer();
            }
        }
    }, 1000);
}

function pauseTimer() {
    timer.isPaused = true;
}

function resumeTimer() {
    timer.isPaused = false;
}

function resetTimer() {
    clearInterval(timer.intervalId);
    timer.isRunning = false;
    timer.isPaused = false;
    timer.remainingTime = timer.currentPhase === "Learning"
        ? timer.learningTime
        : timer.breakTime;
    timer.intervalId = null;
}

chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    switch (request.type) {
        case "notification":
            notify(request.message);
            break;
        case "start":
            startTimer();
            break;
        case "pause":
            pauseTimer();
            break;
        case "resume":
            resumeTimer();
            break;
        case "reset":
            resetTimer();
            break;
        case "getState":
            sendResponse({ ...timer });
            return true;
        case "setLearningTime":
            timer.learningTime = request.seconds;
            if (!timer.isRunning && timer.currentPhase === "Learning") {
                timer.remainingTime = request.seconds;
            }
            break;
        case "setBreakTime":
            timer.breakTime = request.seconds;
            if (!timer.isRunning && timer.currentPhase === "Break") {
                timer.remainingTime = request.seconds;
            }
            break;
    }
});
