let currentState = {
    isRunning: false,
    isPaused: false,
    currentPhase: "Learning",
    remainingTime: 30 * 60,
    learningTime: 30 * 60,
    breakTime: 5 * 60,
};

const countdownEl = document.getElementById("countdown");
const startButton = document.getElementById("startButton");
const resetButton = document.getElementById("resetButton");
const phaseIndicator = document.getElementById("phase-indicator");
const playIcon = document.getElementById("playicon");

const learningButtons = document.querySelectorAll(".learning-button");
const breakButtons = document.querySelectorAll(".break-button");

function formatTime(seconds) {
    const min = Math.floor(seconds / 60).toString().padStart(2, '0');
    const sec = (seconds % 60).toString().padStart(2, '0');
    return `${min}:${sec}`;
}

function updateDisplay() {
    countdownEl.textContent = formatTime(currentState.remainingTime);
    phaseIndicator.textContent = `${currentState.currentPhase} Phase`;
    updatePlayButton();
    toggleTimeButtons(!(currentState.isRunning && !currentState.isPaused));
    setActiveButton(learningButtons, currentState.learningTime);
    setActiveButton(breakButtons, currentState.breakTime);

    if (currentState.currentPhase === "Learning") {
        phaseIndicator.classList.add("learning-phase");
        phaseIndicator.classList.remove("break-phase");
    } else {
        phaseIndicator.classList.add("break-phase");
        phaseIndicator.classList.remove("learning-phase");
    }
}

function updatePlayButton() {
    playIcon.src = currentState.isRunning && !currentState.isPaused
        ? "pause.png"
        : "play-button.png";
}

function toggleTimeButtons(enabled) {
    [...learningButtons, ...breakButtons].forEach(btn => {
        btn.disabled = !enabled;
    });
}

function setActiveButton(buttons, selectedTime) {
    buttons.forEach(btn => {
        const val = parseInt(btn.dataset.time) * 60;
        btn.classList.toggle("active", val === selectedTime);
    });
}

function getState() {
    chrome.runtime.sendMessage({ type: "getState" }, (response) => {
        if (!response) return;
        currentState = response;
        updateDisplay();
    });
}

function sendMessage(type) {
    chrome.runtime.sendMessage({ type });
}

function updateLearningTime(seconds) {
    chrome.runtime.sendMessage({ type: "setLearningTime", seconds });

    if (currentState.currentPhase === "Learning") {
        chrome.runtime.sendMessage({ type: "reset" }, () => {
            setTimeout(getState, 100);
        });
    } else {
        currentState.learningTime = seconds;
        setActiveButton(learningButtons, seconds);
    }
}

function updateBreakTime(seconds) {
    chrome.runtime.sendMessage({ type: "setBreakTime", seconds });

    if (currentState.currentPhase === "Break") {
        chrome.runtime.sendMessage({ type: "reset" }, () => {
            setTimeout(getState, 100);
        });
    } else {
        currentState.breakTime = seconds;
        setActiveButton(breakButtons, seconds);
    }
}

learningButtons.forEach(btn => {
    btn.addEventListener("click", () => {
        const seconds = parseInt(btn.dataset.time) * 60;
        updateLearningTime(seconds);
    });
});

breakButtons.forEach(btn => {
    btn.addEventListener("click", () => {
        const seconds = parseInt(btn.dataset.time) * 60;
        updateBreakTime(seconds);
    });
});

startButton.addEventListener("click", () => {
    if (!currentState.isRunning) {
        sendMessage("start");
    } else if (currentState.isPaused) {
        sendMessage("resume");
    } else {
        sendMessage("pause");
    }
    setTimeout(getState, 100);
});

resetButton.addEventListener("click", () => {
    sendMessage("reset");
    setTimeout(getState, 100);
});

setInterval(getState, 1000);
window.addEventListener("DOMContentLoaded", getState);
